package com.ynet.life.net.sftp;

import com.jcraft.jsch.ChannelSftp;
import com.jcraft.jsch.JSch;
import com.jcraft.jsch.Session;
import com.jcraft.jsch.SftpATTRS;
import com.jcraft.jsch.SftpException;
import com.ynet.gene.service.GENEService;
import com.ynet.life.exception.TranFailException;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Vector;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_ynet_life_net_sftp.jar:com/ynet/life/net/sftp/SftpService.class */
public class SftpService extends GENEService {
    private String sftpServerAddress = null;
    private int port = 22;
    private String user = null;
    private String password = null;
    private int timeout = 3000;
    private static final TranFailException EXCEPTION_LOGIN = new TranFailException("EBLN0000", "SFTP服务器登录失败");
    private static final TranFailException EXCEPTION_FILE_TRANSFER = new TranFailException("EBLN0000", "文件传输失败");
    private static final TranFailException EXCEPTION_GENERAL = new TranFailException("EBLN0000", "SFTP IO异常");

    public Session getSftpSession() throws TranFailException {
        try {
            JSch jsch = new JSch();
            System.out.println("sftp服务" + this.user + "|" + this.sftpServerAddress + "|" + this.port);
            Session session = jsch.getSession(this.user, this.sftpServerAddress, this.port);
            if (session == null) {
                throw EXCEPTION_LOGIN;
            }
            session.setPassword(this.password);
            session.setConfig("StrictHostKeyChecking", "no");
            session.connect(this.timeout);
            return session;
        } catch (Exception unused) {
            throw EXCEPTION_LOGIN;
        }
    }

    public ChannelSftp getSftpClient(Session session) throws TranFailException {
        try {
            ChannelSftp openChannel = session.openChannel("sftp");
            openChannel.connect(1000);
            ChannelSftp sftp = openChannel;
            return sftp;
        } catch (Exception unused) {
            throw EXCEPTION_LOGIN;
        }
    }

    public void mkdirFile(ChannelSftp sftptemp, String dirName, boolean rootFlag) throws TranFailException {
        if (dirName.indexOf("\\") != -1) {
            dirName = dirName.replaceAll("\\", "/");
        }
        String[] dirs = dirName.substring(1).split("/");
        if (rootFlag) {
            try {
                sftptemp.cd("/");
            } catch (Exception unused) {
                throw EXCEPTION_GENERAL;
            }
        }
        for (int i = 0; i < dirs.length; i++) {
            try {
                sftptemp.cd(dirs[i]);
            } catch (SftpException unused2) {
                sftptemp.mkdir(dirs[i]);
                sftptemp.cd(dirs[i]);
            }
        }
    }

    public void uploadFile(ChannelSftp sftptemp, String fileName, String dstName) throws TranFailException {
        FileInputStream fi = null;
        try {
            try {
                if (StringUtils.isEmpty(fileName)) {
                    String nowPath = sftptemp.pwd();
                    Vector<ChannelSftp.LsEntry> v = sftptemp.ls(nowPath);
                    List<Map<String, String>> fileList = buildFiles(v);
                    if (fileList.size() > 0) {
                        for (Map<String, String> file : fileList) {
                            if (StringUtils.equals("false", file.get("dir"))) {
                                String fileNameTemp = file.get("name");
                                File fileTemp = new File(fileNameTemp);
                                fi = new FileInputStream(fileTemp);
                                sftptemp.put(fi, fileTemp.getName());
                                fi.close();
                            }
                        }
                    }
                } else {
                    fi = new FileInputStream(new File(fileName));
                    String dstDir = dstName.substring(0, dstName.lastIndexOf("/"));
                    mkdirFile(sftptemp, dstDir, true);
                    sftptemp.put(fi, dstName);
                    fi.close();
                }
                if (fi != null) {
                    try {
                        fi.close();
                    } catch (IOException unused) {
                    }
                }
            } catch (Throwable th) {
                if (0 != 0) {
                    try {
                        fi.close();
                    } catch (IOException unused2) {
                    }
                }
                throw th;
            }
        } catch (Exception unused3) {
            if (0 != 0) {
                try {
                    fi.close();
                } catch (IOException unused4) {
                }
            }
            throw EXCEPTION_FILE_TRANSFER;
        }
    }

    public void downloadFile(ChannelSftp sftp, String downLoadFile, String fileName) throws TranFailException {
        try {
            sftp.get(downLoadFile, fileName);
        } catch (Exception unused) {
            throw EXCEPTION_FILE_TRANSFER;
        }
    }

    public List<Map<String, String>> buildFiles(Vector<ChannelSftp.LsEntry> ls) throws TranFailException {
        if (ls != null && ls.size() >= 0) {
            List<Map<String, String>> list = new ArrayList<>();
            for (int i = 0; i < ls.size(); i++) {
                ChannelSftp.LsEntry f = ls.get(i);
                String nm = f.getFilename();
                if (!StringUtils.equals(nm, ".") && !StringUtils.equals(nm, "..")) {
                    SftpATTRS attr = f.getAttrs();
                    Map<String, String> map = new HashMap<>();
                    if (attr.isDir()) {
                        map.put("dir", "true");
                    } else {
                        map.put("dir", "false");
                    }
                    map.put("name", nm);
                    list.add(map);
                }
            }
            return list;
        }
        return null;
    }

    public void setSftpServerAddress(String sftpServerAddress) {
        this.sftpServerAddress = sftpServerAddress;
    }

    public void setUser(String user) {
        this.user = user;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public void setPort(String port) {
        try {
            this.port = Integer.parseInt(port);
        } catch (NumberFormatException unused) {
            this.port = 22;
        }
    }

    public void setTimeout(String timeout) {
        try {
            this.timeout = Integer.parseInt(timeout);
        } catch (NumberFormatException unused) {
            this.timeout = 3000;
        }
    }

    public static void main(String[] args) {
    }
}
